ipc_call

Function ipc_call 

pub fn ipc_call(
    port_handle: usize,
    msg: &mut IpcMessage,
) -> Result<usize, Error>
Send a message and block until a reply arrives (RPC-style).

On return the message buffer is overwritten with the reply.